@@ -1,10 +1,19 @@
 """Module that actually performs the ping, sending and receiving packets"""
 
-import os, sys
+import os
+import sys
+from enum import IntEnum, auto
+
 from . import icmp
 from . import network
 
 
+class SuccessOn(IntEnum):
+    One = auto()
+    Most = auto()
+    All = auto()
+
+
 class Message:
     """Represents an ICMP message with destination socket"""
     def __init__(self, target, packet, source):
@@ -127,6 +136,24 @@ class ResponseList:
         for response in initial_set:
             self.append(response)
 
+    def success(self, option=SuccessOn.One):
+        """Check success state of the request.
+
+        :param option: Sets a threshold for success sign. ( 1 - SuccessOn.One, 2 - SuccessOn.Most, 3 - SuccessOn.All )
+        :type option: int
+        :return: Whether this set of responses is successful
+        :rtype: bool
+        """
+        result = False
+        success_list = [resp.success for resp in self._responses]
+        if option == SuccessOn.One:
+            result = True in success_list
+        elif option == SuccessOn.Most:
+            result = success_list.count(True) / len(success_list) > 0.5
+        elif option == SuccessOn.All:
+            result = False not in success_list
+        return result
+
     @property
     def rtt_min_ms(self):
         return represent_seconds_in_ms(self.rtt_min)
@@ -169,6 +196,10 @@ class ResponseList:
         ret += 'Round Trip Times min/avg/max is {0}/{1}/{2} ms'.format(self.rtt_min_ms, self.rtt_avg_ms, self.rtt_max_ms)
         return ret
 
+    def __iter__(self):
+        for response in self._responses:
+            yield response
+
 
 class Communicator:
     """Instance actually communicating over the network, sending messages and handling responses"""
